Mathematical Functions
======================

.. https://docs.scipy.org/doc/numpy/reference/routines.math.html

Trigonometric functions
-----------------------

.. autosummary::
   :toctree: generated/
   :nosignatures:

   cupy.sin
   cupy.cos
   cupy.tan
   cupy.arcsin
   cupy.arccos
   cupy.arctan
   cupy.hypot
   cupy.arctan2
   cupy.degrees
   cupy.radians
   cupy.unwrap
   cupy.deg2rad
   cupy.rad2deg


Hyperbolic functions
--------------------

.. autosummary::
   :toctree: generated/
   :nosignatures:

   cupy.sinh
   cupy.cosh
   cupy.tanh
   cupy.arcsinh
   cupy.arccosh
   cupy.arctanh


Rounding
--------

.. autosummary::
   :toctree: generated/
   :nosignatures:

   cupy.around
   cupy.round_
   cupy.rint
   cupy.fix
   cupy.floor
   cupy.ceil
   cupy.trunc


Sums, products, differences
---------------------------

.. autosummary::
   :toctree: generated/
   :nosignatures:

   cupy.prod
   cupy.sum
   cupy.cumprod
   cupy.cumsum
   cupy.nansum
   cupy.nanprod
   cupy.diff


Exponents and logarithms
------------------------

.. autosummary::
   :toctree: generated/
   :nosignatures:

   cupy.exp
   cupy.expm1
   cupy.exp2
   cupy.log
   cupy.log10
   cupy.log2
   cupy.log1p
   cupy.logaddexp
   cupy.logaddexp2


Other special functions
-----------------------

.. autosummary::
   :toctree: generated/
   :nosignatures:

   cupy.i0
   cupy.sinc


Floating point routines
-----------------------

.. autosummary::
   :toctree: generated/
   :nosignatures:

   cupy.signbit
   cupy.copysign
   cupy.frexp
   cupy.ldexp
   cupy.nextafter


Arithmetic operations
---------------------

.. autosummary::
   :toctree: generated/
   :nosignatures:

   cupy.add
   cupy.reciprocal
   cupy.negative
   cupy.multiply
   cupy.divide
   cupy.power
   cupy.subtract
   cupy.true_divide
   cupy.floor_divide
   cupy.fmod
   cupy.mod
   cupy.modf
   cupy.remainder
   cupy.divmod


Handling complex numbers
------------------------

.. autosummary::
   :toctree: generated/
   :nosignatures:

   cupy.angle
   cupy.real
   cupy.imag
   cupy.conj


Miscellaneous
-------------

.. autosummary::
   :toctree: generated/
   :nosignatures:

   cupy.convolve
   cupy.clip
   cupy.sqrt
   cupy.cbrt
   cupy.square
   cupy.absolute
   cupy.sign
   cupy.maximum
   cupy.minimum
   cupy.fmax
   cupy.fmin
   cupy.nan_to_num
   cupy.bartlett
   cupy.blackman
   cupy.hamming
   cupy.hanning
   cupy.kaiser
